Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch struct device * -> device_t, struct cfdata * -> cfd...



details:   https://anonhg.NetBSD.org/src/rev/3266dbf22d3a
branches:  trunk
changeset: 765776:3266dbf22d3a
user:      matt <matt%NetBSD.org@localhost>
date:      Sun Jun 05 17:03:16 2011 +0000

description:
struct device * -> device_t, struct cfdata * -> cfdata_t
CFATTACH_DECL(*, sizeof(struct device), -> CFATTACH_DECL_NEW(&, 0

diffstat:

 sys/arch/algor/dev/mainbus.c           |  18 +++++++++---------
 sys/arch/amigappc/amigappc/cpu.c       |  14 +++++++-------
 sys/arch/amigappc/amigappc/mainbus.c   |  14 +++++++-------
 sys/arch/arm/mainbus/cpu_mainbus.c     |  18 +++++++++---------
 sys/arch/arm/mainbus/mainbus.c         |  24 ++++++++++++------------
 sys/arch/emips/emips/mainbus.c         |  14 +++++++-------
 sys/arch/evbppc/ev64260/mainbus.c      |   8 ++++----
 sys/arch/evbppc/pmppc/mainbus.c        |  26 +++++++++++++-------------
 sys/arch/luna68k/luna68k/mainbus.c     |  14 +++++++-------
 sys/arch/mac68k/mac68k/mainbus.c       |  18 +++++++++---------
 sys/arch/macppc/macppc/cpu.c           |  18 +++++++++---------
 sys/arch/macppc/macppc/mainbus.c       |  14 +++++++-------
 sys/arch/mmeye/mmeye/mainbus.c         |  10 +++++-----
 sys/arch/mvme68k/dev/mainbus.c         |  14 +++++++-------
 sys/arch/mvmeppc/mvmeppc/cpu.c         |  14 +++++++-------
 sys/arch/mvmeppc/mvmeppc/mainbus.c     |  14 +++++++-------
 sys/arch/next68k/next68k/mainbus.c     |  18 +++++++++---------
 sys/arch/ofppc/ofppc/cpu.c             |  20 ++++++++++----------
 sys/arch/ofppc/ofppc/mainbus.c         |  14 +++++++-------
 sys/arch/powerpc/ibm4xx/cpu.c          |  14 +++++++-------
 sys/arch/prep/prep/cpu.c               |  14 +++++++-------
 sys/arch/prep/prep/mainbus.c           |  14 +++++++-------
 sys/arch/rs6000/rs6000/cpu.c           |  14 +++++++-------
 sys/arch/rs6000/rs6000/mainbus.c       |  14 +++++++-------
 sys/arch/sandpoint/sandpoint/mainbus.c |  24 ++++++++++++------------
 sys/arch/shark/ofw/cpu_ofbus.c         |  14 +++++++-------
 26 files changed, 206 insertions(+), 206 deletions(-)

diffs (truncated from 1441 to 300 lines):

diff -r 73cb5552b5ff -r 3266dbf22d3a sys/arch/algor/dev/mainbus.c
--- a/sys/arch/algor/dev/mainbus.c      Sun Jun 05 16:59:21 2011 +0000
+++ b/sys/arch/algor/dev/mainbus.c      Sun Jun 05 17:03:16 2011 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: mainbus.c,v 1.21 2011/02/20 07:51:21 matt Exp $        */
+/*     $NetBSD: mainbus.c,v 1.22 2011/06/05 17:03:18 matt Exp $        */
 
 /*-
  * Copyright (c) 2001 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: mainbus.c,v 1.21 2011/02/20 07:51:21 matt Exp $");
+__KERNEL_RCSID(0, "$NetBSD: mainbus.c,v 1.22 2011/06/05 17:03:18 matt Exp $");
 
 #include "opt_algor_p4032.h"
 #include "opt_algor_p5064.h"
@@ -63,14 +63,14 @@
 #include "locators.h"
 #include "pci.h"
 
-int    mainbus_match(struct device *, struct cfdata *, void *);
-void   mainbus_attach(struct device *, struct device *, void *);
+int    mainbus_match(device_t, cfdata_t, void *);
+void   mainbus_attach(device_t, device_t, void *);
 
-CFATTACH_DECL(mainbus, sizeof(struct device),
+CFATTACH_DECL_NEW(mainbus, 0,
     mainbus_match, mainbus_attach, NULL, NULL);
 
 int    mainbus_print(void *, const char *);
-int    mainbus_submatch(struct device *, struct cfdata *,
+int    mainbus_submatch(device_t, cfdata_t,
                         const int *, void *);
 
 /* There can be only one. */
@@ -125,7 +125,7 @@
 #endif /* ALGOR_P6032 */
 
 int
-mainbus_match(struct device *parent, struct cfdata *cf, void *aux)
+mainbus_match(device_t parent, cfdata_t cf, void *aux)
 {
 
        if (mainbus_found)
@@ -135,7 +135,7 @@
 }
 
 void
-mainbus_attach(struct device *parent, struct device *self, void *aux)
+mainbus_attach(device_t parent, device_t self, void *aux)
 {
        struct mainbus_attach_args ma;
        struct mainbusdev *md;
@@ -247,7 +247,7 @@
 }
 
 int
-mainbus_submatch(struct device *parent, struct cfdata *cf,
+mainbus_submatch(device_t parent, cfdata_t cf,
                 const int *ldesc, void *aux)
 {
        struct mainbus_attach_args *ma = aux;
diff -r 73cb5552b5ff -r 3266dbf22d3a sys/arch/amigappc/amigappc/cpu.c
--- a/sys/arch/amigappc/amigappc/cpu.c  Sun Jun 05 16:59:21 2011 +0000
+++ b/sys/arch/amigappc/amigappc/cpu.c  Sun Jun 05 17:03:16 2011 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: cpu.c,v 1.1 2009/07/21 09:49:15 phx Exp $      */
+/*     $NetBSD: cpu.c,v 1.2 2011/06/05 17:03:16 matt Exp $     */
 
 /*-
  * Copyright (c) 2008,2009 Frank Wille.
@@ -29,7 +29,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: cpu.c,v 1.1 2009/07/21 09:49:15 phx Exp $");
+__KERNEL_RCSID(0, "$NetBSD: cpu.c,v 1.2 2011/06/05 17:03:16 matt Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -41,16 +41,16 @@
 
 #include <amiga/amiga/device.h>
 
-int cpu_match(struct device *, struct cfdata *, void *);
-void cpu_attach(struct device *, struct device *, void *);
+int cpu_match(device_t, cfdata_t, void *);
+void cpu_attach(device_t, device_t, void *);
 
-CFATTACH_DECL(cpu, sizeof(struct device),
+CFATTACH_DECL_NEW(cpu, 0,
     cpu_match, cpu_attach, NULL, NULL);
 
 extern struct cfdriver cpu_cd;
 
 int
-cpu_match(struct device *parent, struct cfdata *cf, void *aux)
+cpu_match(device_t parent, cfdata_t cf, void *aux)
 {
 
        if (strcmp((char *)aux, cpu_cd.cd_name) != 0)
@@ -61,7 +61,7 @@
 }
 
 void
-cpu_attach(struct device *parent, struct device *self, void *aux)
+cpu_attach(device_t parent, device_t self, void *aux)
 {
 
        if (amiga_realconfig)
diff -r 73cb5552b5ff -r 3266dbf22d3a sys/arch/amigappc/amigappc/mainbus.c
--- a/sys/arch/amigappc/amigappc/mainbus.c      Sun Jun 05 16:59:21 2011 +0000
+++ b/sys/arch/amigappc/amigappc/mainbus.c      Sun Jun 05 17:03:16 2011 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: mainbus.c,v 1.2 2010/05/21 12:52:14 phx Exp $  */
+/*     $NetBSD: mainbus.c,v 1.3 2011/06/05 17:03:16 matt Exp $ */
 
 /*-
  * Copyright (c) 2008,2009 Frank Wille.
@@ -58,7 +58,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: mainbus.c,v 1.2 2010/05/21 12:52:14 phx Exp $");
+__KERNEL_RCSID(0, "$NetBSD: mainbus.c,v 1.3 2011/06/05 17:03:16 matt Exp $");
 
 #include <sys/param.h>
 #include <sys/device.h>
@@ -79,22 +79,22 @@
 #endif
 #endif
 
-void mbattach(struct device *, struct device *, void *);
+void mbattach(device_t, device_t, void *);
 int mbprint(void *, const char *);
-int mbmatch(struct device *, struct cfdata *, void *);
+int mbmatch(device_t, cfdata_t, void *);
 
-CFATTACH_DECL(mainbus, sizeof(struct device),
+CFATTACH_DECL_NEW(mainbus, 0,
     mbmatch, mbattach, NULL, NULL);
 
 int
-mbmatch(struct device *parent, struct cfdata *cfp, void *aux)
+mbmatch(device_t parent, cfdata_t cfp, void *aux)
 {
 
        return 1;
 }
 
 void
-mbattach(struct device *parent, struct device *self, void *aux)
+mbattach(device_t parent, device_t self, void *aux)
 {
 
        printf("\n");
diff -r 73cb5552b5ff -r 3266dbf22d3a sys/arch/arm/mainbus/cpu_mainbus.c
--- a/sys/arch/arm/mainbus/cpu_mainbus.c        Sun Jun 05 16:59:21 2011 +0000
+++ b/sys/arch/arm/mainbus/cpu_mainbus.c        Sun Jun 05 17:03:16 2011 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: cpu_mainbus.c,v 1.10 2009/03/14 15:36:02 dsl Exp $     */
+/*     $NetBSD: cpu_mainbus.c,v 1.11 2011/06/05 17:03:16 matt Exp $    */
 
 /*
  * Copyright (c) 1995 Mark Brinicombe.
@@ -42,7 +42,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: cpu_mainbus.c,v 1.10 2009/03/14 15:36:02 dsl Exp $");
+__KERNEL_RCSID(0, "$NetBSD: cpu_mainbus.c,v 1.11 2011/06/05 17:03:16 matt Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -63,33 +63,33 @@
 /*
  * Prototypes
  */
-static int cpu_mainbus_match(struct device *, struct cfdata *, void *);
-static void cpu_mainbus_attach(struct device *, struct device *, void *);
+static int cpu_mainbus_match(device_t, cfdata_t, void *);
+static void cpu_mainbus_attach(device_t, device_t, void *);
  
 /*
  * int cpumatch(struct device *parent, struct cfdata *cf, void *aux)
  *
  * Probe for the main cpu. Currently all this does is return 1 to
  * indicate that the cpu was found.
  */ 
  
 static int
-cpu_mainbus_match(struct device *parent, struct cfdata *cf, void *aux)
+cpu_mainbus_match(device_t parent, cfdata_t cf, void *aux)
 {
        return(1);
 }
 
 /*
  * void cpusattach(struct device *parent, struct device *dev, void *aux)
  *
  * Attach the main cpu
  */
   
 static void
-cpu_mainbus_attach(struct device *parent, struct device *self, void *aux)
+cpu_mainbus_attach(device_t parent, device_t self, void *aux)
 {
        cpu_attach(self);
 }
 
-CFATTACH_DECL(cpu_mainbus, sizeof(struct device),
+CFATTACH_DECL_NEW(cpu_mainbus, 0,
     cpu_mainbus_match, cpu_mainbus_attach, NULL, NULL);
@@ -63,33 +63,33 @@
  
 /*
- * int cpumatch(struct device *parent, struct cfdata *cf, void *aux)
+ * int cpumatch(device_t parent, cfdata_t cf, void *aux)
  *
  * Probe for the main cpu. Currently all this does is return 1 to
@@ -63,33 +63,33 @@
 
 /*
- * void cpusattach(struct device *parent, struct device *dev, void *aux)
+ * void cpusattach(device_t parent, device_t dev, void *aux)
  *
  * Attach the main cpu
diff -r 73cb5552b5ff -r 3266dbf22d3a sys/arch/arm/mainbus/mainbus.c
--- a/sys/arch/arm/mainbus/mainbus.c    Sun Jun 05 16:59:21 2011 +0000
+++ b/sys/arch/arm/mainbus/mainbus.c    Sun Jun 05 17:03:16 2011 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: mainbus.c,v 1.16 2009/03/14 15:36:02 dsl Exp $ */
+/* $NetBSD: mainbus.c,v 1.17 2011/06/05 17:03:16 matt Exp $ */
 
 /*
  * Copyright (c) 1994,1995 Mark Brinicombe.
@@ -42,7 +42,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: mainbus.c,v 1.16 2009/03/14 15:36:02 dsl Exp $");
+__KERNEL_RCSID(0, "$NetBSD: mainbus.c,v 1.17 2011/06/05 17:03:16 matt Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -68,25 +68,25 @@
 
 /* Prototypes for functions provided */
 
-static int  mainbusmatch(struct device *, struct cfdata *, void *);
-static void mainbusattach(struct device *, struct device *, void *);
+static int  mainbusmatch(device_t, cfdata_t, void *);
+static void mainbusattach(device_t, device_t, void *);
 static int  mainbusprint(void *aux, const char *mainbus);
-static int  mainbussearch(struct device *, struct cfdata *,
+static int  mainbussearch(device_t, cfdata_t,
                                const int *, void *);
 
 /* attach and device structures for the device */
 
-CFATTACH_DECL(mainbus, sizeof(struct device),
+CFATTACH_DECL_NEW(mainbus, 0,
     mainbusmatch, mainbusattach, NULL, NULL);
 
 /*
  * int mainbusmatch(struct device *parent, struct cfdata *cf, void *aux)
  *
  * Always match for unit 0
  */
 
 static int
-mainbusmatch(struct device *parent, struct cfdata *cf, void *aux)
+mainbusmatch(device_t parent, cfdata_t cf, void *aux)
 {
        return (1);
 }
@@ -116,13 +116,13 @@
 }
 
 /*
  * int mainbussearch(struct device *parent, struct device *self, void *aux)
  *
  * search routine used during the config of children
  */
 
 static int
-mainbussearch(struct device *parent, struct cfdata *cf, const int *ldesc, void *aux)
+mainbussearch(device_t parent, cfdata_t cf, const int *ldesc, void *aux)
 {
        struct mainbus_attach_args mb;
        int tryagain;
@@ -155,13 +155,13 @@
 }
 
 /*
  * void mainbusattach(struct device *parent, struct device *self, void *aux)
  *
  * probe and attach all children
  */
 
 static void
-mainbusattach(struct device *parent, struct device *self, void *aux)
+mainbusattach(device_t parent, device_t self, void *aux)
 {
        aprint_naive("\n");
        aprint_normal("\n");
@@ -68,25 +68,25 @@
 
 /*
- * int mainbusmatch(struct device *parent, struct cfdata *cf, void *aux)
+ * int mainbusmatch(device_t parent, cfdata_t cf, void *aux)
  *
  * Always match for unit 0
@@ -116,13 +116,13 @@
 
 /*
- * int mainbussearch(struct device *parent, struct device *self, void *aux)
+ * int mainbussearch(device_t parent, device_t self, void *aux)
  *
  * search routine used during the config of children
@@ -155,13 +155,13 @@
 
 /*
- * void mainbusattach(struct device *parent, struct device *self, void *aux)
+ * void mainbusattach(device_t parent, device_t self, void *aux)
  *
  * probe and attach all children
diff -r 73cb5552b5ff -r 3266dbf22d3a sys/arch/emips/emips/mainbus.c



Home | Main Index | Thread Index | Old Index